#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Indicators in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Indicators
{
	public class Zi8CPADX : Indicator
	{
		private int step;

		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description									= @"Enter the description for your new custom Indicator here.";
				Name										= "Zi8CPADX";
				Calculate									= Calculate.OnBarClose;
				IsOverlay									= false;
				DisplayInDataBox							= true;
				DrawOnPricePanel							= true;
				DrawHorizontalGridLines						= true;
				DrawVerticalGridLines						= true;
				PaintPriceMarkers							= true;
				ScaleJustification							= NinjaTrader.Gui.Chart.ScaleJustification.Right;
				//Disable this property if your indicator requires custom values that cumulate with each new market data event. 
				//See Help Guide for additional information.
				IsSuspendedWhileInactive					= true;
				FinalPeriod				= 20;
				Filter					= 200;
				AddPlot(Brushes.Blue, "PlotCPADX");
			}
			else if (State == State.Configure)
			{
			}
			else if (State == State.DataLoaded)
            {
				step = Math.Max(1, FinalPeriod / 20);
            }
		}

		protected override void OnBarUpdate()
		{
			try
			{
				int nA = 0;
				int Ma = 0;

				for (int x = 10; x < FinalPeriod + 1; x += step)
				{
					if (Slope(ADX(x), Filter, 0) < 0)
						Ma++;

					nA++;
				}

				if (nA == 0)
					return;

				Value[0] = (100.0 * Ma / nA);

				if (Value[0] < 80)
					BackBrush = Brushes.Salmon;
				else
					BackBrush = Brushes.Aquamarine;
			}
			catch (Exception ex)
			{
				Print(string.Format("E R R O R  ... \n{0}\n{1}", ex.Message, ex.StackTrace));
			}
		}

		#region Properties
		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="FinalPeriod", Order=1, GroupName="Parameters")]
		public int FinalPeriod
		{ get; set; }

		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="Filter", Order=2, GroupName="Parameters")]
		public int Filter
		{ get; set; }

		[Browsable(false)]
		[XmlIgnore]
		public Series<double> PlotCPADX
		{
			get { return Values[0]; }
		}
		#endregion

	}
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private Zi8CPADX[] cacheZi8CPADX;
		public Zi8CPADX Zi8CPADX(int finalPeriod, int filter)
		{
			return Zi8CPADX(Input, finalPeriod, filter);
		}

		public Zi8CPADX Zi8CPADX(ISeries<double> input, int finalPeriod, int filter)
		{
			if (cacheZi8CPADX != null)
				for (int idx = 0; idx < cacheZi8CPADX.Length; idx++)
					if (cacheZi8CPADX[idx] != null && cacheZi8CPADX[idx].FinalPeriod == finalPeriod && cacheZi8CPADX[idx].Filter == filter && cacheZi8CPADX[idx].EqualsInput(input))
						return cacheZi8CPADX[idx];
			return CacheIndicator<Zi8CPADX>(new Zi8CPADX(){ FinalPeriod = finalPeriod, Filter = filter }, input, ref cacheZi8CPADX);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.Zi8CPADX Zi8CPADX(int finalPeriod, int filter)
		{
			return indicator.Zi8CPADX(Input, finalPeriod, filter);
		}

		public Indicators.Zi8CPADX Zi8CPADX(ISeries<double> input , int finalPeriod, int filter)
		{
			return indicator.Zi8CPADX(input, finalPeriod, filter);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.Zi8CPADX Zi8CPADX(int finalPeriod, int filter)
		{
			return indicator.Zi8CPADX(Input, finalPeriod, filter);
		}

		public Indicators.Zi8CPADX Zi8CPADX(ISeries<double> input , int finalPeriod, int filter)
		{
			return indicator.Zi8CPADX(input, finalPeriod, filter);
		}
	}
}

#endregion
